@@ -14,23 +14,53 @@
 
 // QT includes
 #include <qobject.h>
+#include <qstringlist.h>
 
 // KDE includes
 #include <ksimpleconfig.h>
 #include <kapplication.h>
+#include <klibloader.h>
+#include <kinstance.h>
 
 #include "ksayit_fxplugin.h"
 
-class FreeverbPlugin : public QObject, public FXPlugin
+class FreeverbPluginFactory : public KLibFactory
+{
+Q_OBJECT
+public:
+    // Consturctor
+    FreeverbPluginFactory(QObject *parent=0, const char* name=0);
+    
+    // Destructor
+    virtual ~FreeverbPluginFactory(){ delete p_instance; };
+    
+    QObject* createObject(QObject *parent=0, const char* name=0, 
+            const char* className="QObject", 
+            const QStringList &args=QStringList());        
+
+private:
+    static KInstance* p_instance;
+
+};
+
+
+
+
+
+class FreeverbPlugin : public FXPlugin
 {
 Q_OBJECT
 public: 
     // Constructor
-    FreeverbPlugin(QObject *parent=0, const char* name=0, KApplication *Appl=0);
+    FreeverbPlugin(QObject *parent=0, const char* name=0); //, KApplication *Appl=0);
     
     // Destructor
     ~FreeverbPlugin();    
     
+    /** sets the Main application object
+    */
+    void setApplication(KApplication *Appl);
+    
     /** returns the Name of the Plugin
     */
     QString getName_KS() const;
